==> huaweicloudsdkecs-3.0.84-py2.py3-none-any.whl: huaweicloudsdkecs/v2/model/reinstall_server_without_cloud_init_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ReinstallServerWithoutCloudInitRequestBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'os_reinstall': 'ReinstallServerWithoutCloudInitOption'
    }

    attribute_map = {
        'os_reinstall': 'os-reinstall'
    }

    def __init__(self, os_reinstall=None):
        """ReinstallServerWithoutCloudInitRequestBody - a model defined in huaweicloud sdk"""
        
        

        self._os_reinstall = None
        self.discriminator = None

        self.os_reinstall = os_reinstall

    @property
    def os_reinstall(self):
        """Gets the os_reinstall of this ReinstallServerWithoutCloudInitRequestBody.


        :return: The os_reinstall of this ReinstallServerWithoutCloudInitRequestBody.
        :rtype: ReinstallServerWithoutCloudInitOption
        """
        return self._os_reinstall

    @os_reinstall.setter
    def os_reinstall(self, os_reinstall):
        """Sets the os_reinstall of this ReinstallServerWithoutCloudInitRequestBody.


        :param os_reinstall: The os_reinstall of this ReinstallServerWithoutCloudInitRequestBody.
        :type: ReinstallServerWithoutCloudInitOption
        """
        self._os_reinstall = os_reinstall

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReinstallServerWithoutCloudInitRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkecs-3.0.94-py2.py3-none-any.whl: huaweicloudsdkecs/v2/model/reinstall_server_without_cloud_init_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ReinstallServerWithoutCloudInitRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'os_reinstall': 'ReinstallServerWithoutCloudInitOption'
    }

    attribute_map = {
        'os_reinstall': 'os-reinstall'
    }

    def __init__(self, os_reinstall=None):
        """ReinstallServerWithoutCloudInitRequestBody

        The model defined in huaweicloud sdk

        :param os_reinstall: 
        :type os_reinstall: :class:`huaweicloudsdkecs.v2.ReinstallServerWithoutCloudInitOption`
        """
        
        

        self._os_reinstall = None
        self.discriminator = None

        self.os_reinstall = os_reinstall

    @property
    def os_reinstall(self):
        """Gets the os_reinstall of this ReinstallServerWithoutCloudInitRequestBody.


        :return: The os_reinstall of this ReinstallServerWithoutCloudInitRequestBody.
        :rtype: :class:`huaweicloudsdkecs.v2.ReinstallServerWithoutCloudInitOption`
        """
        return self._os_reinstall

    @os_reinstall.setter
    def os_reinstall(self, os_reinstall):
        """Sets the os_reinstall of this ReinstallServerWithoutCloudInitRequestBody.


        :param os_reinstall: The os_reinstall of this ReinstallServerWithoutCloudInitRequestBody.
        :type os_reinstall: :class:`huaweicloudsdkecs.v2.ReinstallServerWithoutCloudInitOption`
        """
        self._os_reinstall = os_reinstall

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReinstallServerWithoutCloudInitRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
